<?php
$lang['0_product'] = 'Produkt';
$lang['1_service'] = 'Tjeneste';
$lang['2_discount'] = 'Rabatt';
$lang['3_shipping'] = 'Forsendelse';
$lang['4_tax'] = 'Avgift';
$lang['addedit_billingform_template'] = 'Legg til/rediger Faktureringskjema mal';
$lang['addedit_completion_template'] = 'Legg til/rediger Fullf&oslash;r mal';
$lang['addedit_confirmorder_template'] = 'Legg til/rediger Ordre mal';
$lang['addedit_gateway_complete_template'] = 'Legg til/rediger Gateway Fullf&oslash;rt mal';
$lang['addedit_invoice_template'] = 'Legg til/rediger Faktura mal';
$lang['addedit_paymentform_template'] = 'Legg til/rediger Betalingskjema mal';
$lang['address1'] = 'Adresselinje 1';
$lang['address2'] = 'Adresselinje 2';
$lang['address_handling'] = 'Adressebehandling';
$lang['add_msg_template'] = 'Legg til en ny meldingsmal';
$lang['admin_email_addresses'] = 'Komma separert liste med admin e-postadresser &aring; benytte n&aring;r en ny ordre er innsendt';
$lang['admin_email_template'] = 'Admin epostmal';
$lang['amount'] = 'Mengde';
$lang['amt_due'] = 'Skyldig bel&oslash;p';
$lang['any'] = 'Enhver';
$lang['ask_delete'] = 'Er du sikker p&aring; du vil slette denne artikkelen?';
$lang['ask_delete_order'] = 'Er du sikker p&aring; at du vil slette denne ordren?  Normalt er det ikke anbefalt &aring; slette ordre.';
$lang['ask_delete_payment'] = 'Er du sikker p&aring; at du permanent vil fjerne alle poster for denne betalingen?';
$lang['ask_edit_billing'] = 'Er du sikker p&aring; at du vil endre betalingsinformasjonen for denne ordren som spesifisert ovenfor?';
$lang['ask_manual_payment'] = 'Er du sikker p&aring; at du vil belaste kredittkortet manuelt for dette bel&oslash;pet?';
$lang['ask_saveprefs'] = 'Er du sikker p&aring; at du vil endre innstillingene for denne modulen? \nV&aelig;r forsiktig, da feil innstillinger kan &oslash;delegge et fungerende nettsted.';
$lang['ask_setorderstatus'] = 'En mulig ordrestatus endring har blitt oppdaget, &oslash;nsker du &aring; sette status til: ';
$lang['back'] = 'Tilbake';
$lang['back_to_orders'] = 'Tilbake til Ordre';
$lang['backorder'] = 'Restet';
$lang['balancedue'] = 'Balanse skyldig (delbetalt)';
$lang['bill_to'] = 'Regning til';
$lang['billing'] = 'Fakturering';
$lang['billing_address'] = 'Faktura adresse';
$lang['billing_form_templates'] = 'Fakturaskjema mal';
$lang['billing_info'] = 'Faktura informasjon';
$lang['body'] = 'Meldingskropp';
$lang['cancel'] = 'Avbryt';
$lang['cancelled'] = 'Kansellert';
$lang['captcha_title'] = 'Captcha Tekst';
$lang['cart_module'] = 'Cart modul';
$lang['cart_settings'] = 'Cart innstillinger';
$lang['cash'] = 'Kontant';
$lang['cc_AMEX'] = 'American Express ';
$lang['cc_Discover'] = 'Oppdag';
$lang['cc_MasterCard'] = 'Mastercard ';
$lang['cc_Visa'] = 'Visa ';
$lang['city'] = 'By';
$lang['company'] = 'Firma';
$lang['completed'] = 'Fullf&oslash;rt';
$lang['completion_templates'] = 'Fullf&oslash;r maler';
$lang['confirmed'] = 'Bekreftet';
$lang['confirm_order'] = 'Bekreft din ordre';
$lang['confirmation_form_templates'] = 'Bekreftelseskjema mal';
$lang['confirmation_num'] = 'Bekreftelsesnummer';
$lang['cookie'] = 'Benytt adresse lagret i en cookie';
$lang['country'] = 'Land';
$lang['coupon_code'] = 'Verdikupong kode';
$lang['created'] = 'Opprettet';
$lang['created_by'] = 'Opprettet av';
$lang['create_invoice'] = 'Opprett faktura for denne ordre';
$lang['create_invoice_for'] = 'Opprett faktura for ordre %s';
$lang['creditcard'] = 'Kredittkort';
$lang['creditcard_expiry'] = 'Kredittkort utl&oslash;psdato';
$lang['creditcard_number'] = 'Kredittkortnummer';
$lang['creditcard_type'] = 'Kredittkort type';
$lang['creditcard_verifycode'] = 'Bekreftelseskode';
$lang['customer_name'] = 'Kundenavn';
$lang['date'] = 'Dato';
$lang['date_range'] = 'Datoperiode';
$lang['dateopt_exactdates'] = 'Eksakte datoer';
$lang['dateopt_7days'] = 'Siste 7 dager';
$lang['dateopt_14days'] = 'Siste 14 dager';
$lang['dateopt_30days'] = 'Siste 30 dager';
$lang['dateopt_3months'] = 'Siste 3 m&aring;neder';
$lang['dateopt_6months'] = 'Siste 6 m&aring;neder';
$lang['dateopt_1year'] = 'Siste &aring;ret';
$lang['default_templates'] = 'Standard maler';
$lang['delete'] = 'Slett';
$lang['delivered'] = 'Levert';
$lang['description'] = 'Beskrivelse';
$lang['desc_order_by'] = 'Sorter etter {$billing->get_firstname()} {$billing->get_lastname()}';
$lang['destinations'] = 'Forsendelsested';
$lang['details'] = 'Detaljer';
$lang['dflt_billingform_template'] = 'Standard Fakturaskjema mal';
$lang['dflt_confirmorder_template'] = 'Standard Bekreft ordreskjema mal';
$lang['dflt_completion_template'] = 'Standard Fullf&oslash;r mal';
$lang['dflt_gateway_complete_template'] = 'Standard &quot;Gateway Transaction Complete&quot; mal';
$lang['dflt_invoice_message'] = 'Takk for at du handler hos {sitename}.';
$lang['dflt_invoice_template'] = 'Standard Faktura mal';
$lang['dflt_paymentform_template'] = 'Standard Betalingskjema mal';
$lang['discount'] = 'Rabatt';
$lang['edit'] = 'Rediger';
$lang['edit_billing_info'] = 'Rediger betalingsinformasjon';
$lang['edit_report_template'] = 'Redigere mal for rapport: %s';
$lang['end_date'] = 'Sluttdato';
$lang['email'] = 'Epost';
$lang['email_address'] = 'Epostadresse';
$lang['email_invoice'] = 'Send denne fakturaen med epost til kunden og autoriserte administratorer';
$lang['email_sent_to'] = 'Epost sendt til';
$lang['email_subject'] = 'Epost emne';
$lang['error_badcaptcha'] = 'Captcha verdien som ble oppgitt var feil';
$lang['error_creditcard_expired'] = 'Dette kredittkortet er utl&oslash;pt';
$lang['error_encryption_problem'] = 'Det oppstod et problem med kryptering eller dekryptering av data';
$lang['error_gateway_invalid_data'] = 'Kunne ikke bekrefte datagyldighet fra betaling gatewaymodulen';
$lang['error_insufficientparams'] = 'En n&oslash;dvendig parameter manglet';
$lang['error_invalid_address'] = 'Adressen du oppga for &amp;quot;%s&amp;quot; er ugyldig. Vennligst kontroller at du fylte ut alle de p&aring;krevde feltene.';
$lang['error_invalidfield'] = 'F&oslash;lgende felt er ugyldig: %s';
$lang['error_invalidgateway'] = 'Den valgte gateway modulen er ugyldig for dette bruk';
$lang['error_missingshippinginfo'] = 'Ufulstendig forsendelsesinformasjon oppgitt';
$lang['error_namexists'] = 'En artikkel med det navnet eksisterer allerede';
$lang['error_nocartmodule'] = 'Kunne ikke finne Handlevogn(Cart) modulen. Vennligst sjekk at cart modulen er installert og valgt i Products modulens innstillinger.';
$lang['error_noemailaddress'] = 'Ingen epostadresse har blitt koblet til denne userid';
$lang['error_nofeumodule'] = 'Kunne ikke finne FrontEndUsers modulen';
$lang['error_nopaymentgateway'] = 'Ingen betalings gateway spesifisert';
$lang['error_noproductsmodule'] = 'Kunne ikke finne Products modulen';
$lang['error_norequiredgroup'] = 'Vennligst sett den p&aring;krevde medlemskapsgruppen i innstillingsfanen';
$lang['error_notloggedin'] = 'Brukeren er ikke innlogget<em>(eller s&aring; er han ikke medlem av den p&aring;krevde gruppen)</em>';
$lang['error_orderinvalid'] = 'Det er et problem med denneordren (informasjonen er inkonsistent)';
$lang['error_ordernotfound'] = 'Den forespurte ordren kunne ikke bli funnet';
$lang['error_orderprocessing'] = 'en feil oppstod i prosessering av denne ordren (soft fail)';
$lang['error_paymentnotfound'] = 'Den spesifiserte betalingen ble ikke funnet';
$lang['error_possible_hack'] = 'Oppdaget et mulig sikkerhetsbrudd: Din uid (%s) passer ikke med uid (%s) som ble funnet for ordren %s. Vennligst kontakt din systemadministrator.';
$lang['error_requiressl'] = 'Betalingsgatewayen som er valgt for bruk p&aring; dette nettstedet krever en sikker tilkobling, som ikke er opprettet enn&aring;';
$lang['error_retrieve_data'] = 'Et problem oppstod ved fors&oslash;k p&aring; &aring; hente relevant informasjon fra databasen';
$lang['error_save'] = 'Feil ved lagring av en data-artikkel: %s';
$lang['error_security_key'] = 'Krypteringsn&oslash;kkelen for denne transaksjonen kan ikke hentes';
$lang['error_paymentgateway_incompatible'] = 'Den valgte betalingsgateway er inkompatibel med denne bestillingsbehandlingsmodulen. Kontakt administratoren for nettstedet';
$lang['error_permissiondenied'] = 'Tilgang nektet';
$lang['error_unknownstatus'] = 'Mottok en ukjent status fra betalings gatewayen';
$lang['error_usernotingroup'] = 'Innlogget bruker er ikke medlem av den n&oslash;dvendige gruppen';
$lang['fax'] = 'Faks';
$lang['filter'] = 'Filter ';
$lang['first_name'] = 'Fornavn';
$lang['firstpage'] = '<< ';
$lang['friendlyname'] = 'Ordre';
$lang['from'] = 'Fra';
$lang['gateway'] = 'Gateway ';
$lang['gateway_module'] = 'Payment Gateway Modul';
$lang['gateway_complete_templates'] = 'Gateway Fullf&oslash;rt mal';
$lang['gateway_failure_message'] = 'Din transaksjon ble ikke fullf&oslash;rt. Enten ble handlingen avbrutt eller s&aring; inntraff en annen feil. Vennligst dobbelsjekk din betalingsinformasjon og fors&oslash;k igjen. For din bekvemmelighet og for sikkerhetskyld har din handlekurv blitt t&oslash;mt. Takk for at du tar deg tid.';
$lang['general_settings'] = 'Generelle innstillinger';
$lang['get_address_from_feu'] = 'Benytt kundeprofil';
$lang['help_param_invoice_prefix'] = 'Denne parameter tillater &aring; spesifisere opp til 4 bokstaver som benyttes som prefiks n&aring;r fakturanummer genereres. Om dette ikke er angitt, vil prefikset oppgitt i modulens preferanser bli benyttet.';
$lang['help_param_nocaptcha'] = 'Om denne parameter er satt, vil captcha bli sl&aring;tt av';
$lang['help_param_template'] = 'Spesifiser en mal som ikke er standard &aring; benytte for standard handlingen';
$lang['hold'] = 'Vent';
$lang['html'] = 'HTML ';
$lang['html_email'] = 'Send epost i HTML format';
$lang['id'] = 'ID';
$lang['incomplete'] = 'Restordre (delvis levert)';
$lang['info_admin_invoice_template'] = 'Velg en mal som vil bli brukt til sprettoppvisningen av fakturaen for utskrift n&aring;r du jobber med en ordre';
$lang['info_adminemail_template'] = 'Malen kontrollerer utseendet og innholdet p&aring; eposten som blir sendt til den autoriserte administrator n&aring;r en ny ordre innsendt';
$lang['info_allow_anon_checkout'] = 'Hvis aktivert, vil brukere bli p&aring;lagt &aring; ha en gyldig feu innlogging &aring; kunne sjekke ut';
$lang['info_allow_creditcard_entry'] = 'Noen betalings-gatewayer krever at brukeren m&aring; oppgi kredittkortinformasjon p&aring; nettstedet ditt f&oslash;r du sender denne informasjonen til betalingsbehandlingsmotoren. Kredittkortinformasjon vil midlertidig bli lagret i et kryptert format f&oslash;r behandlingen er fullf&oslash;rt eller kansellert. Periodisk rengj&oslash;ring av midlertidig informasjon vil sikre at denne informasjonen ikke beholdes p&aring; serveren din, hvis du ikke aktiverer alternativet for &aring; lagre kredittkortinformasjonen <em> (anbefales ikke) </ em>';
$lang['info_billingpage'] = '<strong>Merk:</strong>Denne preferanse, og andre lignende benyttes for &aring; tillate administratoren &aring; benytte forskjellige CMSMS sider for de forskjellige skjema. Om &quot;none&quot; er spesifisert, s&aring; vil gjeldende side bli benyttet.';
$lang['info_ccprocessing_module'] = 'Denne modulen benyttes for manuell kredittkortbehandling';
$lang['info_coupon_code'] = 'Oppgi en verdikupong kode for en mulig rabatt';
$lang['info_default_templates'] = 'Dette skjema kontrollerer innholdet p&aring; malen n&aring;r du klikker p&aring; &#039;Ny mal&#039; i &#039;bekreftelseskjema mal&#039; fliken. &Aring; endre teksten her vil ikke ha umiddelbart effekt p&aring; hva som kommer frem p&aring; din nettside';
$lang['info_edit_report_template'] = 'Disse malene bestemmer stil og layout for en bestemt rapport';
$lang['info_encryption_key'] = 'Denne n&oslash;kkel blir tilfeldig generert n&aring;r modulen blir installert. V&aelig;r forsiktig n&aring;r du endrer denne verdien om det allerede finnes ordre i systemet.';
$lang['info_forcessl'] = '<strong> Merk: Anbefalt </ strong>. Hvis du tillater kundene &aring; angi kredittkortinformasjon, b&oslash;r du aktivere dette alternativet, og sikre at du har konfigurert netstedet ditt riktig for SSL-tilgang for &aring; sikre at overf&oslash;ring av kredittkortinformasjon er gjort over en kryptert forbindelse.';
$lang['info_gateway_description'] = 'Denne informasjonen sendes til betalings-gatewayen for hver transaksjon, og kan bli brukt som informasjon som f.eks. som det navnet som vises til kundene p&aring; deres kredittkortutskrift. Dette er en smartymal som tillater tilpasning av visningen.';
$lang['info_incomplete_timeout'] = 'Startede bestillinger som ikke har hatt aktivitet i et gitt antall minutter kan settes til ufullstendig automatisk. Sett verdien til 0 for &aring; deaktivere denne funksjonaliteten';
$lang['info_invoicepage'] = '<strong>Merk:</strong> Denne siden benyttes ogs&aring; som vellykket eller feilet side for betalingsmetodene';
$lang['inform_no_cc_processing'] = 'Er du klar over at du bare redigerer eksisterende betalingsinformasjon??\nIngen ny kredittkorttransaksjon vil bli behandlet';
$lang['info_order_notes'] = 'Tilf&oslash;r ekstra merknader til denne ordren';
$lang['info_require_membergroup'] = 'Denne innstillingen gjelder bare om en IKKE tillater at anonyme brukere kan utf&oslash;re en &#039;g&aring; til kassen&#039;';
$lang['info_skip_invoice_page'] = 'Om du tillater brukerne &aring; oppgi betalingsinformasjon,<br/>skal de da fortsette til fakturasiden,<br/>eller direkte til fullf&oslash;r betaling siden?';
$lang['info_store_creditcard_data'] = '<strong> Merk: <span style=&quot;color: red;&quot;> anbefales ikke </ span> </ strong> Denne informasjonen lagres i databasen. Selv om kryptering brukes til &aring; lagre private data kan det ikke anses for &aring; v&aelig;re sikkert. Det anbefales at dette alternativet ikke blir brukt. I stedet kan du bruke en kompatibel betalingsgateway modul.';
$lang['info_useremail_template'] = 'Denne malen kontrollerer utseendet og innhold p&aring; eposten som blir sendt til brukeren n&aring;r en ny ordre sendes inn';
$lang['info_validcountries'] = 'Angi en liste over land koder og landets navn (&eacute;n oppf&oslash;ring per linje) for de landene som vil dukke opp i adresselisten. F.eks.: US = USA. Hvis ingen verdi er angitt, vil standard listen over land brukes.';
$lang['info_validstates'] = 'Angi en liste over statlige koder og navn (&eacute;n oppf&oslash;ring per linje) for stater eller provinser som vil dukke opp i adresselisten. i.e: AB = Alberta. Hvis ingen verdi er angitt, vil standard staten listen brukes.';
$lang['info_use_integer'] = 'Benytt kun Integer verdier';
$lang['interval_oneday'] = 'En dag';
$lang['interval_onemonth'] = 'En m&aring;ned';
$lang['interval_onequarter'] = 'Et kvartal';
$lang['interval_oneweek'] = 'En uke';
$lang['interval_oneyear'] = 'Et &aring;r';
$lang['interval_twoweeks'] = 'To uker';
$lang['invoice'] = 'Faktura';
$lang['invoiced'] = 'Fakturert';
$lang['invoice_settings'] = 'Faktura innstillinger';
$lang['invoice_templates'] = 'Faktura maler';
$lang['items'] = 'Enheter';
$lang['last_name'] = 'Etternavn';
$lang['last_modified'] = 'Sist endret';
$lang['lastpage'] = ' >>';
$lang['lbl_back'] = 'Tilbake';
$lang['lbl_preferences'] = 'Preferanser';
$lang['lbl_templates'] = 'Maler';
$lang['legend_dates'] = 'Velg datoer';
$lang['legend_reports'] = 'Rapporter';
$lang['message'] = 'Melding';
$lang['message_templates'] = 'Meldingsmaler';
$lang['method'] = 'Metode';
$lang['moddescription'] = 'En enkel ordre prosseseringsmodul';
$lang['modified'] = 'Endret';
$lang['msg_async_transaction'] = 'H&aring;ndterte Asynkron transaksjon %s for ordre %s';
$lang['msg_order_cancelled'] = 'Ordre %s kansellert eller avvist';
$lang['msg_order_error'] = 'En feil oppstod for ordre %s';
$lang['msg_order_payment'] = 'Betaling mottatt for ordre %s.';
$lang['msg_order_pending'] = 'Ordrestatus endret til &quot;P&aring; vent&quot; p&aring; %s';
$lang['msg_payment_cancelled'] = 'Betaling %s ble kansellert for ordren %s';
$lang['msg_payment_declined'] = 'Betaling %s ble godkjent for ordren %s';
$lang['msg_payment_error'] = 'En feil oppstod ved betaling %s for ordre %s';
$lang['msg_payment_received'] = 'Betaling %s (%s) ble mottatt for ordre %s';
$lang['msg_payment_removed'] = 'Betaling fjernet fra ordren';
$lang['msg_payment_setbackwards'] = 'Fors&oslash;kte &aring; sette status for bestillingen % tilbake fra BETALT(PAID) til VENTER(PENDING)';
$lang['name'] = 'Navn';
$lang['net'] = 'Netto';
$lang['net_price'] = 'Nettopris';
$lang['new_order_submitted'] = 'En ny ordre har blitt sendt inn';
$lang['next'] = 'Neste';
$lang['nextpage'] = ' >';
$lang['no'] = 'Nei';
$lang['no_items_in_cart'] = 'Det er ingen artikler i din handlekurv. Vennligst legg til noen f&oslash;r du fors&oslash;ker &aring; g&aring; til kassa.';
$lang['no_report_data'] = 'Ingen passende data funnet';
$lang['none'] = 'Ingen';
$lang['notcancelledshipped'] = 'Alle, med unntak av kansellerte eller sendte';
$lang['notes'] = 'Notater';
$lang['notshipped'] = 'Ikke sendt';
$lang['num'] = 'Nr.';
$lang['online'] = 'on-line ';
$lang['order'] = 'Ordre';
$lang['orders'] = 'Ordre';
$lang['order_confirm_form_templates'] = 'Bekreft ordreskjema maler';
$lang['order_details'] = 'Ordredetaljer';
$lang['order_notes'] = 'Ordrenotater';
$lang['order_number'] = 'Ordrenr.';
$lang['order_processing'] = 'Ordrebehandling';
$lang['order_statistics'] = 'Ordrestatistikk';
$lang['order_summary'] = 'Ordresammendrag';
$lang['ORDERS_ITEMTYPE_DISCOUNT'] = 'Rabatt';
$lang['paid'] = 'Betalt';
$lang['payment_amount'] = 'Sum betalt';
$lang['payment_approved'] = 'Godkjent';
$lang['payment_cancelled'] = 'Kansellert';
$lang['payment_date'] = 'Betalingsdato';
$lang['payment_declined'] = 'Avvist';
$lang['payment_error'] = 'Feil';
$lang['payment_form_templates'] = 'Betalingskjema maler';
$lang['payment_gateway_settings'] = 'Payment Gateway Innstillinger';
$lang['payment_history'] = 'Betalingshistorikk';
$lang['payment_info'] = 'Betalingsinformasjon';
$lang['payment_method'] = 'Betalingsm&aring;te';
$lang['payment_notprocessed'] = 'Ikke behandlet';
$lang['payment_options'] = 'Betalingsm&aring;ter';
$lang['payment_other'] = 'Annen';
$lang['payment_pending'] = 'Forest&aring;ende';
$lang['payment_status'] = 'Betalingstatus';
$lang['pending'] = 'P&aring; vent';
$lang['phone'] = 'Telefon';
$lang['popup_new_window'] = 'La faktura sprette opp i nytt vindu';
$lang['postinstall'] = 'Ordre modulen har blitt installert';
$lang['postuninstall'] = 'Ordre modulen og alle tilh&oslash;rende data har blitt fjernet';
$lang['post_order_msg'] = 'Etter ordre melding';
$lang['postal'] = 'Postnummer';
$lang['preferences'] = 'Innstillinger';
$lang['prevpage'] = '< ';
$lang['price'] = 'Pris';
$lang['print_invoice'] = 'Skriv ut denne faktura';
$lang['procede_manual_checkout'] = 'Fortsett til manuell utsjekking';
$lang['process_manual_payment'] = 'Prosesser manuell betaling';
$lang['process_new_transaction'] = 'Prosesser kredittkort transaskjonen gjennom gatewayen';
$lang['process_order'] = 'Prosesser ordre';
$lang['product_id'] = 'ProduktID';
$lang['promotions_module'] = 'Promotions Modul';
$lang['promotions_settings'] = 'Promotions innstillinger';
$lang['prompt_address_property_map'] = 'Adresse til FEU egenskapkart';
$lang['prompt_address_retrieval'] = 'Adresse innhentingsmetode';
$lang['prompt_admin_invoice_template'] = 'Faktura utskriftmal';
$lang['prompt_allow_anon_checkout'] = 'Tillat anonyme brukere &aring; sjekke ut i kassen';
$lang['prompt_allow_creditcard_entry'] = 'Tillat kunde &aring; oppgi kredittkort informasjon';
$lang['prompt_billingpage'] = 'Side det skal antas at regningskjemaet skal vises p&aring;. Dette er vanligvis siden med din <code>{Orders}</code> tagg.';
$lang['prompt_ccprocessing_module'] = 'Kredittkort prosesseringsgateway';
$lang['prompt_confirmpage'] = 'Side &aring; benytte for bekreftelseskjemaet';
$lang['prompt_datastore_timeout'] = 'Utl&oslash;psperiode for midlertidig transaksjonsinformasjon';
$lang['prompt_date_search_type'] = 'Filtrer poster som er';
$lang['prompt_dflt_country'] = 'Standard land';
$lang['prompt_dflt_state'] = 'Standard stat';
$lang['prompt_email'] = 'E-postadresse';
$lang['prompt_encryption_key'] = 'Krypteringsn&oslash;kkel';
$lang['prompt_forcessl'] = 'Omdiriger siden til HTTPS for innskriving av betalingsinformasjonen';
$lang['prompt_gateway_description'] = 'Beskrivelse &aring; sende til batalings gatewayen';
$lang['prompt_incomplete_timeout'] = 'Automatisk satt ordrer til ufullstendig <em>(om foresl&aring;tt)</ em> etter N minutter';
$lang['prompt_invoice_message'] = 'Melding som skal st&aring; p&aring; toppen av alle fakturaer';
$lang['prompt_invoicepage'] = 'Side &aring; benytte for faktura og takk for handelen visning';
$lang['prompt_of'] = 'av';
$lang['prompt_ordernum_prefix'] = 'OrderNum Prefiks';
$lang['prompt_page'] = 'Side';
$lang['prompt_pagelimit'] = 'Antall ordre per side';
$lang['prompt_paymentpage'] = 'Side &aring; benytte for betalingskjemaet';
$lang['prompt_permit_deletion'] = 'Tillat sletting av ordre';
$lang['prompt_requirepostal'] = 'Postnummer er et p&aring;krevd felt p&aring; faktureringsskjemaet';
$lang['prompt_requirestate'] = 'State/Province er et p&aring;krevd felt p&aring; faktureringsskjemaet';
$lang['prompt_skip_invoice_page'] = 'Hopp over fakturasiden';
$lang['prompt_store_creditcard_data'] = 'Oppbevar kredittkortinformasjon for alltid';
$lang['prompt_template'] = 'Meldingsmal';
$lang['prompt_username'] = 'Brukernavn';
$lang['prompt_validcountries'] = 'Gyldige land:';
$lang['prompt_validstates'] = 'Gyldige stater:';
$lang['proposed'] = 'P&aring; vent)Proposed)';
$lang['quantity'] = 'Mengde';
$lang['really_uninstall'] = 'Er du sikker p&aring; at du vil gj&oslash;re dette? Alle data tilh&oslash;rende denne modulen vil g&aring; tapt om du fortsetter';
$lang['records_matching_query'] = 'Antall poster som passer din sp&oslash;rring';
$lang['regex'] = 'Vanlig utrykk(Regular Expression)';
$lang['remember_last_address_used'] = 'Benytt adressen fra forrige ordre';
$lang['report'] = 'Rapport';
$lang['reports'] = 'Rapporter';
$lang['report_recent_payments'] = 'Nylige betalinger';
$lang['report_shipping_costs'] = 'Forsendelsekostnader';
$lang['report_subscr_picklist'] = 'Abonnement plukkliste';
$lang['report_templates'] = 'Rapportmaler';
$lang['return'] = 'Tilbake';
$lang['require_group_membership'] = 'Krev at alle brukere som fortsetter til ordrestadiet er medlem av denne FEU-gruppen';
$lang['security_settings'] = 'Sikkerhetsinnstilliinger';
$lang['select_action'] = 'Velg handling';
$lang['select_one'] = 'Velg en';
$lang['select_invoice_template'] = 'Velg fakturamal';
$lang['send'] = 'Send ';
$lang['send_message'] = 'Send en melding til denne kunden';
$lang['sent'] = 'Sendt';
$lang['ship_to'] = 'Send til';
$lang['shipped'] = 'Sendt';
$lang['shipping'] = 'Forsendelse';
$lang['shipping_address'] = 'Leveringsadresse';
$lang['shipping_costs'] = 'Forsendelseskostnader';
$lang['shipping_info'] = 'Leveringsinformasjon';
$lang['shipping_info_for'] = 'Forsendelsesadresse for';
$lang['shipping_info_if_different'] = 'Leveringsinformasjon<em>(Om annen enn fakturainformasjonen)</em>';
$lang['shipping_message'] = 'Melding relatert til dette forsendelsested';
$lang['shipping_module'] = 'Shipping modul';
$lang['shipping_settings'] = 'Shipping innstillinger';
$lang['shipping_total'] = 'Forsendelses total';
$lang['sku'] = 'V.nr.';
$lang['source'] = 'Kilde';
$lang['special_instructions'] = 'Spesielle instruksjoner';
$lang['start_date'] = 'Startdato';
$lang['state/province'] = 'Stat/Provins';
$lang['status'] = 'Status ';
$lang['subscription'] = 'Abonnement';
$lang['subject'] = 'Emne';
$lang['submit'] = 'Utf&oslash;r';
$lang['submitted'] = 'Utf&oslash;rt';
$lang['submit_payment_info'] = 'Send betalingsinformasjon';
$lang['subscribed'] = 'Abonnert';
$lang['subtotal'] = 'Subtotal ';
$lang['tax'] = 'Avgift';
$lang['tax_module'] = 'Tax modul';
$lang['tax_settings'] = 'Tax innstillinger';
$lang['template'] = 'Mal';
$lang['template_name'] = 'Malnavn';
$lang['thank_you_for_order'] = 'Takk for at du handler fra {sitename}';
$lang['timeout'] = 'Tidsavbrutt';
$lang['title_adminemail_template'] = 'Administrator epostadresse';
$lang['title_first_page'] = 'G&aring; f&oslash;rste side';
$lang['title_last_page'] = 'G&aring; til siste side';
$lang['title_manage_order'] = 'Behandle ordre';
$lang['title_manual_process'] = 'Manuell transaksjonsbehandling';
$lang['title_next_page'] = 'G&aring; til neste side';
$lang['title_prev_page'] = 'G&aring; til forrige side';
$lang['title_useremail_template'] = 'Bruker epostadresse';
$lang['to'] = 'Til';
$lang['total'] = 'Total ';
$lang['tracking_num'] = 'Sporingsnummer';
$lang['transaction_id'] = 'TransaksjonsID';
$lang['transaction_successful'] = 'Betaling vellykket gjennomf&oslash;rt';
$lang['type'] = 'Type ';
$lang['update_status'] = 'Oppdater status';
$lang['unit_price'] = 'Enhetspris';
$lang['unit_weight'] = 'Enhetsvekt';
$lang['unknown'] = 'Ukjent';
$lang['unlimited'] = 'Ubegrenset';
$lang['username'] = 'Brukernavn';
$lang['user_email_template'] = 'Bruker epost mal';
$lang['view'] = 'Vis';
$lang['view_message'] = 'Vis melding';
$lang['view_messages'] = 'Vis meldinger relatert til denne ordre';
$lang['warning_https'] = '<strong>Advarsel!</strong> Du benytter ikke en sikker (https) tilkobling. Det er ikke anbefalt at du fortsetter med denne handlingen uten en sikker tilkobling.';
$lang['warning_manual_process'] = '<strong>Advarsel!</strong> Dette skjermbildet tillater manuell gjennomf&oslash;ring av kredittkortbetalinger ved &aring; benytte en online gateway. V&aelig;r forsiktig!';
$lang['warning_orderstatus_paid'] = '<strong>Advarsel!</strong> - Denne ordren har allerede blitt betalt. Du skal ikke gjennomf&oslash;re en manuell betaling for denne ordren';
$lang['warning_orderstatus_cancelled'] = '<strong>Advarsel!</strong> - Denne ordren har blitt kansellert. Du skal ikke gjennomf&oslash;re en manuell betaling for denne ordren';
$lang['warning_no_ccprocessing_gateway'] = '<strong>Advarsel!</strong> Selv om du kan skrive inn kredittkortinformasjon for en ny eller eksisterende betaling, s&aring; vil ingen online prosessering skje.';
$lang['warning_order_paid_in_full'] = '<strong>Advarsel!</strong> Denne ordren ser ut til &aring; v&aelig;re betalt fullt ut.';
$lang['weight'] = 'Vekt';
$lang['within'] = 'Innenfor';
$lang['yes'] = 'Ja';
$lang['utmz'] = '156861353.1279922282.3039.70.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
$lang['utma'] = '156861353.179052623084110100.1210423577.1280786431.1280789370.3090';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1280789370';
?>
